@@ -3,8 +3,8 @@ nest_ <- function(data, key_col, nest_cols = character()) {
   key_data <- data[[key_column]]
   key_levels <- unique(key_data)
   key_factor <- factor(key_data, levels = key_levels)
-  res <- list()
-  res[[key_column]] <- key_levels
-  res[[key_col]] <- split(data[, nest_cols], key_factor)
-  new_styler_df(res)
+
+  res <- vec_split(data[, nest_cols], key_factor)
+  names(res) <- c(key_column, key_col)
+  res
 }
