@@ -3,11 +3,11 @@
 #' Rule:
 #' * Principle: Function arguments that consist of a braced expression always
 #'   need to start on a new line
-#' * Exception: [...] unless it's the last argument and all other
+#' * Exception: unless it's the last argument and all other
 #'   arguments fit on the line of the function call
-#' * Exception: [...] or they are named.
+#' * Exception: or they are named
 #' * Extension: Also, expressions following on braced expressions also cause a
-#'   line trigger.
+#'   line trigger
 #' @keywords internal
 #' @examplesIf FALSE
 #' tryCatch(
@@ -149,15 +149,21 @@ set_line_break_around_comma_and_or <- function(pd, strict) {
 }
 
 style_line_break_around_curly <- function(strict, pd) {
-  if (is_curly_expr(pd) && nrow(pd) > 2L) {
-    closing_before <- pd$token == "'}'"
-    opening_before <- (pd$token == "'{'")
-    to_break <- lag(opening_before, default = FALSE) | closing_before
-    pd$lag_newlines[to_break] <- ifelse(
-      pd$token[to_break] == "COMMENT",
-      pmin(1L, pd$lag_newlines[to_break]),
-      if (strict) 1L else pmax(1L, pd$lag_newlines[to_break])
-    )
+  if (is_curly_expr(pd)) {
+    n_row <- nrow(pd)
+    if (n_row > 2L) {
+      closing_before <- pd$token == "'}'"
+      opening_before <- (pd$token == "'{'")
+      to_break <- lag(opening_before, default = FALSE) | closing_before
+      pd$lag_newlines[to_break] <- ifelse(
+        pd$token[to_break] == "COMMENT",
+        pmin(1L, pd$lag_newlines[to_break]),
+        if (strict) 1L else pmax(1L, pd$lag_newlines[to_break])
+      )
+    } else if (n_row == 2L) {
+      # pd represents {}
+      pd$lag_newlines[2L] <- 0L
+    }
   } else {
     is_else <- pd$token == "ELSE"
     if (any(pd$token_before[is_else] == "'}'")) {
@@ -201,23 +207,49 @@ style_line_break_around_curly <- function(strict, pd) {
 #' @keywords internal
 #' @seealso style_text_without_curly_curly
 set_line_break_around_curly_curly <- function(pd) {
-  if (is_curly_expr(pd)) {
-    # none after {
-    opening_before <- (pd$token == "'{'") &
-      (pd$token_before == "'{'" | pd$token_after == "'{'")
+  if (!is_curly_expr(pd)) {
+    return(pd)
+  }
 
-    # none before }
-    closing_before <- (pd$token == "'}'") &
-      (pd$token_after == "'}'" | pd$token_before == "'}'")
-    if (any(opening_before) && any(closing_before)) {
-      pos_opening_idx <- lag(opening_before, default = FALSE) & pd$token != "COMMENT"
-      pd$lag_newlines[pos_opening_idx] <- 0L
-      if (any(pos_opening_idx)) {
-        # if line is broken with opening `{`, also break it with closing
-        pd$lag_newlines[closing_before & pd$token_after != "COMMENT"] <- 0L
-      }
+  pd %>%
+    set_line_break_around_outer_curly_curly() %>%
+    set_line_break_around_inner_curly_curly()
+}
+
+set_line_break_around_outer_curly_curly <- function(pd) {
+  # none after {
+  opening_before <- (pd$token == "'{'") & (pd$token_after == "'{'")
+  # none before }
+  closing_before <- (pd$token == "'}'") & (pd$token_before == "'}'")
+
+  if (any(opening_before) && any(closing_before)) {
+    pos_opening_idx <- lag(opening_before, default = FALSE) & pd$token != "COMMENT"
+    pd$lag_newlines[pos_opening_idx] <- 0L
+    if (any(pos_opening_idx)) {
+      # if line is broken with opening `{`, also break it with closing
+      pd$lag_newlines[closing_before & pd$token_before != "COMMENT"] <- 0L
     }
   }
+
+  pd
+}
+
+set_line_break_around_inner_curly_curly <- function(pd) {
+  # none before {
+  opening_before <- (pd$token == "'{'") & (pd$token_before == "'{'")
+  # none after }
+  closing_before <- (pd$token == "'}'") & (pd$token_after == "'}'")
+
+  if (any(opening_before) && any(closing_before)) {
+    pos_opening_idx <- lag(opening_before, default = FALSE) & pd$token != "COMMENT"
+    can_remove_line_break_closing <- closing_before & pd$token_before != "COMMENT"
+    if (any(pos_opening_idx) && any(can_remove_line_break_closing)) {
+      pd$lag_newlines[pos_opening_idx] <- 0L
+      # if line is broken with opening `{`, also break it with closing
+      pd$lag_newlines[can_remove_line_break_closing] <- 0L
+    }
+  }
+
   pd
 }
 
@@ -228,23 +260,25 @@ remove_line_break_before_round_closing_after_curly <- function(pd) {
   pd
 }
 
-remove_line_breaks_in_fun_dec <- function(pd) {
+remove_line_breaks_in_function_declaration <- function(pd) {
   if (is_function_declaration(pd)) {
-    is_double_indention <- is_double_indent_function_declaration(pd)
+    is_single_indention <- is_single_indent_function_declaration(pd)
     round_after <- (
       pd$token == "')'" | pd$token_before == "'('"
     ) &
       pd$token_before != "COMMENT"
     pd$lag_newlines[pd$lag_newlines > 1L] <- 1L
-    pd$lag_newlines[round_after] <- 0L
-    if (is_double_indention) {
+    if (is_single_indention) {
       pd$lag_newlines[lag(pd$token == "'('")] <- 1L
+      pd$lag_newlines[round_after] <- 1L
+    } else {
+      pd$lag_newlines[round_after] <- 0L
     }
   }
   pd
 }
 
-#'
+
 add_line_break_after_pipe <- function(pd) {
   is_pipe <- pd$token %in% c("SPECIAL-PIPE", "PIPE")
   pd$lag_newlines[lag(is_pipe) & pd$lag_newlines > 1L] <- 1L
@@ -302,7 +336,9 @@ set_line_break_after_opening_if_call_is_multi_line <- function(pd,
   if (!is_function_call(pd) && !is_subset_expr(pd)) {
     return(pd)
   }
-  has_force_text_before <- last(pd$child[[1L]]$text) %in% force_text_before
+  idx <- length(pd$child[[1L]]$text)
+  has_force_text_before <-
+    pd$child[[1L]]$text[idx] %in% force_text_before && pd$child[[1L]]$token[idx] == "SYMBOL_FUNCTION_CALL"
   if (has_force_text_before) {
     break_pos <- c(
       which(lag(pd$token %in% c("','", "COMMENT"))),
@@ -417,3 +453,31 @@ set_line_break_after_ggplot2_plus <- function(pd) {
   }
   pd
 }
+
+
+remove_empty_lines_after_opening_and_before_closing_braces <- function(pd) {
+  opening_braces <- c("'('", "'['", "LBB")
+  closing_braces <- c("')'", "']'")
+
+  paren_after <- pd$token %in% opening_braces
+  if (any(paren_after)) {
+    pd$lag_newlines[
+      lag(pd$token %in% opening_braces) & pd$lag_newlines > 1L
+    ] <- 1L
+  }
+
+  paren_before <- pd$token %in% closing_braces
+  if (any(paren_before)) {
+    pd$lag_newlines[
+      pd$token %in% closing_braces & pd$lag_newlines > 1L
+    ] <- 1L
+  }
+
+  pd
+}
+
+
+set_line_breaks_between_top_level_exprs <- function(pd, allowed_blank_lines = 2L) {
+  pd$lag_newlines <- pmin(pd$lag_newlines, allowed_blank_lines + 1L)
+  pd
+}
