@@ -4,7 +4,7 @@
 #' @include token-define.R
 #' @keywords internal
 #' @include token-define.R
-set_space_around_op <- function(pd_flat, strict) {
+set_space_around_operator <- function(pd_flat, strict) {
   # spacing and operator in same function because alternative is
   # calling token_is_on_aligned_line() twice because comma and operator spacing
   # depends on it.
@@ -122,7 +122,7 @@ style_space_around_tilde <- function(pd_flat, strict) {
   pd_flat
 }
 
-remove_space_after_unary_pm_nested <- function(pd) {
+remove_space_after_unary_plus_minus_nested <- function(pd) {
   if (any(pd$token[1L] %in% c("'+'", "'-'"))) {
     pd$spaces[1L] <- 0L
   }
@@ -131,7 +131,8 @@ remove_space_after_unary_pm_nested <- function(pd) {
 }
 
 remove_space_before_opening_paren <- function(pd_flat) {
-  paren_after <- pd_flat$token %in% c("'('", "'['", "LBB")
+  opening_braces <- c("'('", "'['", "LBB")
+  paren_after <- pd_flat$token %in% opening_braces
   if (!any(paren_after)) {
     return(pd_flat)
   }
@@ -141,7 +142,8 @@ remove_space_before_opening_paren <- function(pd_flat) {
 }
 
 remove_space_after_opening_paren <- function(pd_flat) {
-  paren_after <- pd_flat$token %in% c("'('", "'['", "LBB")
+  opening_braces <- c("'('", "'['", "LBB")
+  paren_after <- pd_flat$token %in% opening_braces
   if (!any(paren_after)) {
     return(pd_flat)
   }
@@ -150,7 +152,8 @@ remove_space_after_opening_paren <- function(pd_flat) {
 }
 
 remove_space_before_closing_paren <- function(pd_flat) {
-  paren_after <- pd_flat$token %in% c("')'", "']'")
+  closing_braces <- c("')'", "']'")
+  paren_after <- pd_flat$token %in% closing_braces
   if (!any(paren_after)) {
     return(pd_flat)
   }
@@ -171,8 +174,9 @@ add_space_after_for_if_while <- function(pd_flat) {
 
 #' @rdname set_line_break_around_curly_curly
 #' @keywords internal
-set_space_in_curly_curly <- function(pd) {
+set_space_in_curly <- function(pd) {
   if (is_curly_expr(pd)) {
+    # curly-curly
     after_inner_opening <- pd$token == "'{'" & pd$token_before == "'{'"
     before_inner_closing <- lead(pd$token == "'}'" & pd$token_after == "'}'")
     is_curly_curly_inner <- any(after_inner_opening, na.rm = TRUE) &&
@@ -190,6 +194,10 @@ set_space_in_curly_curly <- function(pd) {
       pd$spaces[after_outer_opening] <- 0L
       pd$spaces[before_outer_closing] <- 0L
     }
+
+    # empty curly
+    after_is_empty_curly <- lead(pd$token == "'}'" & pd$token_before == "'{'")
+    pd$spaces[after_is_empty_curly] <- 0L
   }
   pd
 }
@@ -333,14 +341,15 @@ set_space_after_bang_bang <- function(pd_flat) {
   pd_flat
 }
 
-remove_space_before_dollar <- function(pd_flat) {
+remove_space_around_dollar <- function(pd_flat) {
   dollar_after <- (pd_flat$token == "'$'") & (pd_flat$lag_newlines == 0L)
   dollar_before <- lead(dollar_after, default = FALSE)
   pd_flat$spaces[dollar_before] <- 0L
+  pd_flat$spaces[dollar_after] <- 0L
   pd_flat
 }
 
-remove_space_after_fun_dec <- function(pd_flat) {
+remove_space_after_function_declaration <- function(pd_flat) {
   fun_after <- (pd_flat$token == "FUNCTION") & (pd_flat$lag_newlines == 0L)
   pd_flat$spaces[fun_after] <- 0L
   pd_flat
