@@ -76,13 +76,13 @@ tidyverse_style <- function(scope = "tokens",
   indention_manipulators <- if ("indention" %in% scope) {
     list(
       indent_braces = partial(indent_braces, indent_by = indent_by),
-      unindent_fun_dec = unindent_fun_dec,
+      unindent_function_declaration = unindent_function_declaration,
       indent_op = partial(indent_op, indent_by = indent_by),
       indent_eq_sub = partial(indent_eq_sub, indent_by = indent_by),
       indent_without_paren = partial(indent_without_paren,
         indent_by = indent_by
       ),
-      update_indention_ref_fun_dec = update_indention_ref_fun_dec
+      update_indention_reference_function_declaration = update_indention_reference_function_declaration
     )
   }
   space_manipulators <- if ("spaces" %in% scope) {
@@ -102,19 +102,19 @@ tidyverse_style <- function(scope = "tokens",
         style_space_around_tilde,
         strict = strict
       ),
-      spacing_around_op = purrr::partial(set_space_around_op,
+      spacing_around_op = purrr::partial(set_space_around_operator,
         strict = strict
       ),
       remove_space_after_opening_paren = remove_space_after_opening_paren,
       remove_space_after_excl = remove_space_after_excl,
       set_space_after_bang_bang = set_space_after_bang_bang,
-      remove_space_before_dollar = remove_space_before_dollar,
-      remove_space_after_fun_dec = remove_space_after_fun_dec,
+      remove_space_around_dollar = remove_space_around_dollar,
+      remove_space_after_function_declaration = remove_space_after_function_declaration,
       remove_space_around_colons = remove_space_around_colons,
       start_comments_with_space = partial(start_comments_with_space,
         force_one = start_comments_with_one_space
       ),
-      remove_space_after_unary_pm_nested = remove_space_after_unary_pm_nested,
+      remove_space_after_unary_plus_minus_nested = remove_space_after_unary_plus_minus_nested,
       spacing_before_comments = if (strict) {
         set_space_before_comments
       } else {
@@ -122,7 +122,7 @@ tidyverse_style <- function(scope = "tokens",
       },
       set_space_between_levels = set_space_between_levels,
       set_space_between_eq_sub_and_comma = set_space_between_eq_sub_and_comma,
-      set_space_in_curly_curly = set_space_in_curly_curly
+      set_space_in_curly = set_space_in_curly
     )
   }
 
@@ -130,13 +130,17 @@ tidyverse_style <- function(scope = "tokens",
 
   line_break_manipulators <- if ("line_breaks" %in% scope) {
     list(
+      remove_empty_lines_after_opening_and_before_closing_braces =
+        remove_empty_lines_after_opening_and_before_closing_braces,
       set_line_break_around_comma_and_or = set_line_break_around_comma_and_or,
       set_line_break_after_assignment = set_line_break_after_assignment,
       set_line_break_before_curly_opening = set_line_break_before_curly_opening,
       remove_line_break_before_round_closing_after_curly =
         if (strict) remove_line_break_before_round_closing_after_curly,
-      remove_line_breaks_in_fun_dec =
-        if (strict) remove_line_breaks_in_fun_dec,
+      remove_line_breaks_in_function_declaration =
+        if (strict) remove_line_breaks_in_function_declaration,
+      set_line_breaks_between_top_level_exprs =
+        if (strict) set_line_breaks_between_top_level_exprs,
       style_line_break_around_curly = partial(
         style_line_break_around_curly,
         strict
@@ -176,10 +180,10 @@ tidyverse_style <- function(scope = "tokens",
       force_assignment_op = force_assignment_op,
       resolve_semicolon = resolve_semicolon,
       add_brackets_in_pipe = add_brackets_in_pipe,
-      wrap_if_else_while_for_fun_multi_line_in_curly =
+      wrap_if_else_while_for_function_multi_line_in_curly =
         if (strict) {
           purrr::partial(
-            wrap_if_else_while_for_fun_multi_line_in_curly,
+            wrap_if_else_while_for_function_multi_line_in_curly,
             indent_by = indent_by
           )
         }
@@ -201,24 +205,24 @@ tidyverse_style <- function(scope = "tokens",
       # remove_space_after_opening_paren = c("'('", "'['", "LBB"),
       remove_space_after_excl = "'!'",
       set_space_after_bang_bang = "'!'",
-      remove_space_before_dollar = "'$'",
-      remove_space_after_fun_dec = "FUNCTION",
+      remove_space_around_dollar = "'$'",
+      remove_space_after_function_declaration = "FUNCTION",
       remove_space_around_colons = c("':'", "NS_GET_INT", "NS_GET"),
       start_comments_with_space = "COMMENT",
-      remove_space_after_unary_pm_nested = c("'+'", "'-'"),
+      remove_space_after_unary_plus_minus_nested = c("'+'", "'-'"),
       spacing_before_comments = "COMMENT",
-      set_space_in_curly_curly = c("'{'", "'}'")
+      set_space_in_curly = c("'{'", "'}'")
     ),
     indention = list(
       # indent_braces = c("'('", "'['", "'{'", "')'", "']'", "'}'"),
-      unindent_fun_dec = "FUNCTION",
+      unindent_function_declaration = "FUNCTION",
       indent_eq_sub = c("EQ_SUB", "EQ_FORMALS"), # TODO rename
-      update_indention_ref_fun_dec = "FUNCTION"
+      update_indention_reference_function_declaration = "FUNCTION"
     ),
     line_breaks = list(
       set_line_break_before_curly_opening = "'{'",
       remove_line_break_before_round_closing_after_curly = "'}'",
-      remove_line_breaks_in_fun_dec = "FUNCTION",
+      remove_line_breaks_in_function_declaration = "FUNCTION",
       set_line_break_around_curly_curly = "'{'",
       style_line_break_around_curly = "'{'",
       add_line_break_after_pipe = c("SPECIAL-PIPE", "PIPE")
@@ -226,12 +230,8 @@ tidyverse_style <- function(scope = "tokens",
     tokens = list(
       resolve_semicolon = "';'",
       add_brackets_in_pipe = c("SPECIAL-PIPE", "PIPE"),
-      # before 3.6, these assignments are not wrapped into top-level expression
-      # and `text` supplied to transformers_drop() is "", so it appears to not
-      # contain EQ_ASSIGN, and the transformer is falsely removed.
-      # compute_parse_data_nested / text_to_flat_pd ('a = 4')
       force_assignment_op = "EQ_ASSIGN",
-      wrap_if_else_while_for_fun_multi_line_in_curly = c(
+      wrap_if_else_while_for_function_multi_line_in_curly = c(
         "IF", "WHILE", "FOR", "FUNCTION"
       )
     )
