@@ -19,7 +19,7 @@
 #' @keywords internal
 test_collection <- function(test, sub_test = NULL,
                             dry = "off",
-                            write_tree = NA,
+                            write_tree = FALSE,
                             transformer,
                             ...) {
   path <- rprojroot::find_testthat_root_file(test)
@@ -93,9 +93,7 @@ construct_tree <- function(in_paths, suffix = "_tree") {
 #' @param out_name The label of the out_item, defaults to `out_item`.
 #' @param transformer A function to apply to the content of `in_item`.
 #' @param write_tree Whether or not the tree structure of the test should be
-#'   computed and written to a file. Note that this needs R >= 3.2
-#'   (see [set_arg_write_tree()]). If the argument is set to `NA`, the function
-#'   determines whether R >= 3.2 is in use and if so, trees will be written.
+#'   computed and written to a files.
 #' @param ... Parameters passed to transformer function.
 #' @param out_tree Name of tree file if written out.
 #' @inheritParams transform_utf8
@@ -103,9 +101,9 @@ construct_tree <- function(in_paths, suffix = "_tree") {
 transform_and_check <- function(in_item, out_item,
                                 in_name = in_item, out_name = out_item,
                                 transformer, dry,
-                                write_tree = NA,
+                                write_tree = FALSE,
                                 out_tree = "_tree", ...) {
-  write_tree <- set_arg_write_tree(write_tree)
+  if (write_tree) check_installed("data.tree")
   read_in <- read_utf8_bare(in_item)
   if (write_tree) {
     create_tree(read_in) %>%
@@ -119,7 +117,7 @@ transform_and_check <- function(in_item, out_item,
     unclass()
   if (!file.exists(out_item)) {
     warn(paste(
-      "File", out_item, "does not exist. Creating it from transormation."
+      "File", out_item, "does not exist. Creating it from transformation."
     ))
     file.create(out_item)
   }
@@ -269,48 +267,6 @@ n_times_faster_bench <- function(i, x1, x2, fun, ..., n, clear) {
   )
 }
 
-
-#' Generate a comprehensive collection test cases for comment / insertion
-#' interaction
-#' Test consist of if / if-else / if-else-if-else cases, paired with various
-#' line-break and comment configurations. Used for internal testing.
-#' @return
-#' The function is called for its side effects, i.e. to write the
-#' test cases to *-in.R files that can be tested with [test_collection()]. Note
-#' that a few of the test cases are invalid and need to be removed / commented
-#' out manually.
-#' @keywords internal
-generate_test_samples <- function() {
-  gen <- function(x) {
-    if (length(x) == 0L) {
-      ""
-    } else {
-      c(
-        paste0(x[1L], gen(x[-1L])),
-        paste0(x[1L], " # comment\n", paste(x[-1L], collapse = ""))
-      )
-    }
-  }
-
-  collapse <- function(x) paste(x, collapse = "\n\n")
-
-  cat(
-    collapse(gen(c("if", "(", "TRUE", ")", "NULL"))),
-    file = "tests/testthat/insertion_comment_interaction/just_if-in.R"
-  )
-  cat(
-    collapse(gen(c("if", "(", "TRUE", ")", "NULL", " else", " NULL"))),
-    file = "tests/testthat/insertion_comment_interaction/if_else-in.R"
-  )
-  cat(
-    collapse(gen(c(
-      "if", "(", "TRUE", ")", "NULL", " else", " if", "(", "FALSE", ")", "NULL",
-      " else", " NULL"
-    ))),
-    file = "tests/testthat/insertion_comment_interaction/if_else_if_else-in.R"
-  )
-}
-
 #' @include ui-caching.R
 clear_testthat_cache <- purrr::partial(cache_clear, "testthat", ask = FALSE)
 activate_testthat_cache <- purrr::partial(cache_activate, "testthat")
