@@ -9,7 +9,7 @@ hash_standardize <- function(text) {
   text %>%
     convert_newlines_to_linebreaks() %>%
     enc2utf8() %>%
-    paste0(collapse = "\n") %>%
+    paste(collapse = "\n") %>%
     list()
 }
 
@@ -54,7 +54,7 @@ is_cached <- function(text,
 #'   a new cache.
 #' * transformers. Cannot easily hash them because two environments won't be
 #'   identical even if they contain the same objects (see 'Experiments'). Simple
-#'   `as.character(transformers)` will not consider infinitively recursive
+#'   `as.character(transformers)` will not consider infinitely recursive
 #'   code dependencies.
 #'   To fix this, transformers must have names and version number as described
 #'   in [create_style_guide()]. Now, the only way to fool the cache invalidation
@@ -137,7 +137,7 @@ cache_is_activated <- function(cache_name = NULL) {
     return(cache_name == current_cache)
   }
 
-  return(FALSE)
+  FALSE
 }
 
 #' Cache text
@@ -163,7 +163,7 @@ cache_by_expression <- function(text,
   } else {
     expressions$stylerignore <- rep(FALSE, length(expressions$text))
   }
-  # TODO base_indention should be set to 0  on write and on read for expressions
+  # TODO base_indention should be set to 0 on write and on read for expressions
   # (only) to make it possible to use the cache for expressions with different
   # indention. when not the whole input text is cached, we go trough all
   # expressions and check if they are cached, if yes, we take the input (from
