@@ -112,3 +112,43 @@ call({{
 {{
   #
 }}
+
+
+call({
+  {
+    1
+  }
+})
+
+call({
+  {
+    1 #
+  }
+})
+
+call({
+  { #
+    1
+  }
+})
+
+call({
+  {
+    1
+  } #
+})
+
+
+call({
+  {
+    1
+  }
+} #
+)
+
+call({ #
+  {
+    1
+  }
+}
+)
