@@ -111,3 +111,31 @@ call({{
 {{
   #
 }}
+
+
+call({{ 1 }})
+
+call({{
+  1 #
+}})
+
+call({{ #
+  1
+}})
+
+call({
+  {
+    1
+  } #
+})
+
+
+call(
+  {{ 1 }} #
+)
+
+call({ #
+  {
+    1
+  }
+})
