@@ -23,5 +23,4 @@
 )))
 
 
-function(x, y, z) {
-}
+function(x, y, z) {}
