@@ -19,6 +19,14 @@ fac[
 ]
 
 fac[, `:`(a = c)
+]
+
+fac[
+
+  , `:`(a = c)
+
+
+
 ]
 
 x[a ==3 |
@@ -44,3 +52,36 @@ x[a ==3 &&
 
 x[a ==3 &
    b == v,]
+
+x[
+
+  # comments above
+  a ==3 &
+    b == v,
+  # or below shouldn't be an issue
+
+
+  ]
+
+
+x[
+
+  a,
+  b
+
+
+]
+
+x[
+
+  # this comment shouldn't be an issue
+  1, c(
+
+  1, 2
+
+  # neither should this one
+
+  )
+
+
+]
