@@ -88,6 +88,14 @@ blew(y = 2, x |>
   a |> c() + 1
 }
 
+{
+  (
+    # some comment
+
+    a |> c() + 1
+  )
+}
+
 b |>
   f() |> # never move comment to next line as it can be styler: off or nolint
   k() |>
