@@ -1,8 +1,6 @@
 test(
   "x",
-  {
-
-  },
+  {},
   a + b,
   {
     s(x = sd)
@@ -11,9 +9,7 @@ test(
 
 test(
   "x",
-  {
-
-  },
+  {},
   a + b,
   {
     s(x = sd)
@@ -22,9 +18,7 @@ test(
 
 test(
   "x",
-  {
-
-  },
+  {},
   a + b,
   {
     s(x = sd)
@@ -34,9 +28,7 @@ test(
 
 test(
   "x",
-  {
-
-  },
+  {},
   a + b,
   {
     s(x = sd)
@@ -45,9 +37,7 @@ test(
 
 test(
   "x",
-  {
-
-  }, # h
+  {}, # h
   a + b,
   {
     s(x = sd)
@@ -56,9 +46,7 @@ test(
 
 test(
   "x",
-  {
-
-  }, # h
+  {}, # h
   a + b,
   # k
   {
@@ -68,9 +56,7 @@ test(
 
 test(
   "x",
-  {
-
-  },
+  {},
   a + b, # k
   {
     s(x = sd)
