@@ -18,3 +18,14 @@ mpg %>%
 , avg_hwy = mean(hwy)
 , n = n()
 , n_class = n_distinct(class))
+
+
+1:4 %>% {
+
+
+    (
+
+        . + 1
+    )
+
+}
