@@ -41,3 +41,21 @@ test_that(
     # comment
     expect_equal(1 + 1, 2)
   })
+
+
+while (TRUE) { }
+
+while (TRUE)
+  { }
+
+while (TRUE){
+
+ }
+
+while (TRUE){
+#
+ }
+
+
+while (TRUE){#
+ }
