@@ -16,7 +16,6 @@ switch( #
 )
 
 
-
 switch(x,
   a = 2, #
   y = 3
@@ -76,3 +75,6 @@ dplyr::ifelse(
   x,
   1, 32
 )
+
+# variable name 'switch' is different
+l$switch[1:3, ]
