@@ -7,8 +7,7 @@ call(call(
   2
 ))
 # multi-line: no indention based on first vall
-call(a(b(c({
-}))))
+call(a(b(c({}))))
 
 call(
   call(
