@@ -10,7 +10,7 @@
 #'   pd_flat
 #' }
 #' set_line_break_before_curly_opening_style <- function() {
-#'   create_style_guide(line_break = tibble::lst(set_line_break_before_curly_opening))
+#'   create_style_guide(line_break = list(set_line_break_before_curly_opening))
 #' }
 #' style_text("a <- function(x) { x }
 #' ", style = set_line_break_before_curly_opening_style)
@@ -30,9 +30,9 @@ create_style_guide <- function(initialize = default_style_guide_attributes,
                                indention = NULL,
                                use_raw_indention = FALSE,
                                reindention = tidyverse_reindention()) {
-  lst(
+  list(
     # transformer functions
-    initialize = lst(initialize),
+    initialize = list(initialize),
     line_break,
     space,
     token,
