@@ -1,5 +1,4 @@
-a <- function(x) {
-}
+a <- function(x) {}
 
 if (a) {
   3
@@ -13,5 +12,4 @@ if (x) {
   y
 } else if (x) {
   x
-} else {
-}
+} else {}
