@@ -1,6 +1,8 @@
 test_that("activated cache brings speedup on style_file() API", {
   local_test_setup()
   skip_on_cran()
+  skip_on_covr()
+  skip_during_parallel()
   n <- n_times_faster_with_cache(
     test_path("reference-objects/caching.R"),
     test_path("reference-objects/caching.R"),
@@ -25,6 +27,8 @@ text <- c(
 
 test_that("activated cache brings speedup on style_text() API on character vector", {
   skip_on_cran()
+  skip_on_covr()
+  skip_during_parallel()
   n <- n_times_faster_with_cache(
     text, text,
     fun = style_text
@@ -34,6 +38,8 @@ test_that("activated cache brings speedup on style_text() API on character vecto
 
 test_that("activated cache brings speedup on style_text() API on character scalar", {
   skip_on_cran()
+  skip_on_covr()
+  skip_during_parallel()
   text2 <- paste0(text, collapse = "\n")
 
   n <- n_times_faster_with_cache(
@@ -52,6 +58,8 @@ test_that("trailing line breaks are ignored for caching", {
   style_text(text2)
   expect_equal(cache_info(format = "tabular")$n, 3)
   skip_on_cran()
+  skip_on_covr()
+  skip_during_parallel()
   n <- n_times_faster_with_cache(text1, text2)
   expect_gt(n, 55)
 })
@@ -64,6 +72,8 @@ test_that("trailing line breaks are ignored for caching in one scalar", {
   style_text(text2)
   expect_equal(cache_info(format = "tabular")$n, 3)
   skip_on_cran()
+  skip_on_covr()
+  skip_during_parallel()
   n <- n_times_faster_with_cache(text1, text2)
   expect_gt(n, 55)
 })
@@ -79,13 +89,16 @@ test_that("trailing line breaks are ignored for caching in one scalar", {
   style_text(text2)
   expect_equal(cache_info(format = "tabular")$n, 3)
   skip_on_cran()
+  skip_on_covr()
+  skip_during_parallel()
   n <- n_times_faster_with_cache(text1, text2)
   expect_gt(n, 55)
 })
 
 test_that("speedup higher when cached roxygen example code is multiple expressions", {
   skip_on_cran()
-
+  skip_on_covr()
+  skip_during_parallel()
   text_long <- c(
     "#' Roxygen",
     "#' Comment",
@@ -116,7 +129,7 @@ test_that("speedup higher when cached roxygen example code is multiple expressio
   )
   # the speed gain for longer expression is 1.1x higher
   expect_true(
-    speedup_multiple_roygen_example / speedup_many_roygen_examples > 1.03
+    speedup_multiple_roygen_example / speedup_many_roygen_examples > 1.02
   )
 })
 
@@ -124,18 +137,22 @@ test_that("speedup higher when cached roxygen example code is multiple expressio
 
 test_that("no speedup when tranformer changes", {
   skip_on_cran()
+  skip_on_covr()
+  skip_during_parallel()
   local_test_setup()
   t1 <- tidyverse_style()
   first <- system.time(style_text(text, transformers = t1))
   t1 <- tidyverse_style(indent_by = 4)
   second <- system.time(style_text(text, transformers = t1))
-  expect_false(first["elapsed"] / 1.3 > second["elapsed"])
+  expect_true(first["elapsed"] < 1.3 * second["elapsed"])
 })
 
 
 test_that("unactivated cache does not bring speedup", {
-  skip_on_cran
+  skip_on_cran()
+  skip_on_covr()
   local_test_setup()
+  skip_during_parallel()
   first <- system.time(style_file(test_path("reference-objects/caching.R")))
   second <- system.time(style_file(test_path("reference-objects/caching.R")))
   expect_false(first["elapsed"] / 4 > second["elapsed"])
