@@ -1,4 +1,4 @@
-test_that("roxzgen code examples are written to cache as both individual expressions and as whole text", {
+test_that("roxyen code examples are written to cache as both individual expressions and as whole text", {
   local_test_setup(cache = TRUE)
   more_specs <- cache_more_specs_default()
   text <- c(
@@ -14,10 +14,10 @@ test_that("roxzgen code examples are written to cache as both individual express
   styled <- style_text(text)
   expect_equal(cache_info(format = "tabular")$n, 6)
   # 1 whole (with comments)
-  # 1code whole
+  # 1 code whole
   # 1 code by expr
-  # 1 roxzgen whole
-  # 2 roxzgen individula
+  # 1 roxygen whole
+  # 2 roxygen individual
   # total: 6
   expect_true(
     is_cached(as.character(styled), tidyverse_style(), more_specs = more_specs)
