@@ -1,6 +1,6 @@
 test_that("curly-culry", {
-  expect_warning(test_collection("curly-curly",
+  expect_no_warning(test_collection("curly-curly",
     "mixed",
     transformer = style_text
-  ), NA)
+  ))
 })
