@@ -1,7 +1,7 @@
 test_that("escaping of characters works", {
-  expect_warning(test_collection("escaping", "basic",
+  expect_no_warning(test_collection("escaping", "basic",
     transformer = style_text
-  ), NA)
+  ))
 
   expect_error(test_collection("escaping", "fail-parsing-1",
     transformer = style_text
