@@ -1,5 +1,5 @@
 test_that("edge cases work", {
-  expect_warning(test_collection("indention_fun_calls",
+  expect_no_warning(test_collection("indention_fun_calls",
     transformer = style_text, strict = FALSE
-  ), NA)
+  ))
 })
