@@ -2,24 +2,24 @@
 ##  strict = TRUE                                                           ####
 
 test_that("token are added correctly to conditional statements", {
-  expect_warning(test_collection(
+  expect_no_warning(test_collection(
     "insertion_comment_interaction", "just_if_strict",
     transformer = style_text
-  ), NA)
+  ))
 })
 
 test_that("token are added correctly to conditional statements", {
-  expect_warning(test_collection(
+  expect_no_warning(test_collection(
     "insertion_comment_interaction", "if_else_strict",
     transformer = style_text
-  ), NA)
+  ))
 })
 
 test_that("token are added correctly to conditional statements", {
-  expect_warning(test_collection(
+  expect_no_warning(test_collection(
     "insertion_comment_interaction", "if_else_if_else_strict",
     transformer = style_text
-  ), NA)
+  ))
 })
 
 
@@ -27,22 +27,22 @@ test_that("token are added correctly to conditional statements", {
 ##  strict = FALSE                                                          ####
 
 test_that("token are added correctly to conditional statements", {
-  expect_warning(test_collection(
+  expect_no_warning(test_collection(
     "insertion_comment_interaction", "just_if_non_strict",
     transformer = style_text, strict = FALSE
-  ), NA)
+  ))
 })
 
 test_that("token are added correctly to conditional statements", {
-  expect_warning(test_collection(
+  expect_no_warning(test_collection(
     "insertion_comment_interaction", "if_else_non_strict",
     transformer = style_text, strict = FALSE
-  ), NA)
+  ))
 })
 
 test_that("token are added correctly to conditional statements", {
-  expect_warning(test_collection(
+  expect_no_warning(test_collection(
     "insertion_comment_interaction", "if_else_if_else_non_strict",
     transformer = style_text, strict = FALSE
-  ), NA)
+  ))
 })
