@@ -2,15 +2,15 @@ library("testthat")
 
 
 test_that("simple multiple expressions are styled correctly", {
-  expect_warning(test_collection("multiple_expressions",
+  expect_no_warning(test_collection("multiple_expressions",
     "two_simple",
     transformer = style_text
-  ), NA)
+  ))
 })
 
 test_that("complex multiple expressions are styled correctly", {
-  expect_warning(test_collection("multiple_expressions",
+  expect_no_warning(test_collection("multiple_expressions",
     "three_complex",
     transformer = style_text
-  ), NA)
+  ))
 })
