@@ -1,57 +1,57 @@
 test_that("can style .Rmd files", {
-  expect_warning(test_collection("rmd", "simple",
+  expect_no_warning(test_collection("rmd", "simple",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
+  ))
 
-  expect_warning(test_collection("rmd", "r_and_non_r_code_chunks",
+  expect_no_warning(test_collection("rmd", "r_and_non_r_code_chunks",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
+  ))
 
-  expect_warning(test_collection("rmd", "nested",
+  expect_no_warning(test_collection("rmd", "nested",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
+  ))
 
-  expect_warning(test_collection("rmd", "invalid",
+  expect_no_warning(test_collection("rmd", "invalid",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
+  ))
 
   ## new 3-5
-  expect_warning(test_collection("rmd", "random3",
+  expect_no_warning(test_collection("rmd", "random3",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
-  expect_warning(test_collection("rmd", "random5",
+  ))
+  expect_no_warning(test_collection("rmd", "random5",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
-  expect_warning(test_collection("rmd", "random6",
+  ))
+  expect_no_warning(test_collection("rmd", "random6",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
-  expect_warning(test_collection("rmd", "random7",
+  ))
+  expect_no_warning(test_collection("rmd", "random7",
     transformer = transform_mixed,
     transformer_fun = style_text,
     filetype = "Rmd",
     write_tree = FALSE
-  ), NA)
+  ))
 })
 
 
