@@ -1,6 +1,6 @@
 test_that("square brackets cause indention", {
-  expect_warning(test_collection(
+  expect_no_warning(test_collection(
     "indention_square_brackets",
     transformer = style_text
-  ), NA)
+  ))
 })
