@@ -1,5 +1,5 @@
 test_that("leading spaces are preserved at start of text", {
-  expect_warning(test_collection("start_line",
+  expect_no_warning(test_collection("start_line",
     transformer = style_empty
-  ), NA)
+  ))
 })
