@@ -7,7 +7,8 @@
 {
   {
     call(
-      call1(2, 3), {
+      call1(2, 3),
+      {
         sin(cos(pi))
       }
     )
